@@ -4,7 +4,7 @@
 #
 # A Python Jira REST Client
 #
-# (C) 2007,2008,2009,2010,2011,2012: Matthew Callaway
+# (C) 2007-2021: Matthew Callaway
 #
 # jiraclient is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -103,7 +103,7 @@ class SearchableDict(dict):
       else: return None
 
 class Jiraclient(object):
-  version = "2.1.10"
+  version = "2.1.12"
   def __init__(self):
     self.issues_created = []
     self.proxy   = Resource('', filters=[])
@@ -128,7 +128,7 @@ class Jiraclient(object):
     sys.exit(1)
 
   def print_version(self):
-    print "jiraclient version %s" % self.version
+    print("jiraclient version %s" % self.version)
 
   def parse_args(self):
     usage = """%prog [options]
@@ -502,7 +502,7 @@ class Jiraclient(object):
         parser.readfp(file(self.options.config,'r'))
       except ConfigParser.ParsingError:
         self.logger.warning("Body has multiple lines, truncating...")
-      except Exception, details:
+      except Exception as details:
         self.fatal("Unable to parse file at %r: %s" % (self.options.config,details))
 
     for (k,v) in (parser.items('jiraclient')):
@@ -521,7 +521,7 @@ class Jiraclient(object):
       parser.readfp(file(self.options.config,'r'))
     except ConfigParser.ParsingError:
       self.logger.warning("Body has multiple lines, truncating...")
-    except Exception, details:
+    except Exception as details:
       self.fatal("Unable to parse file at %r: %s" % (self.options.config,details))
 
     for (k,v) in (parser.items('issues')):
@@ -551,7 +551,7 @@ class Jiraclient(object):
       if os.path.exists(self.options.sessionfile):
         os.unlink(self.options.sessionfile)
       return None
-    except Exception,msg:
+    except Exception as msg:
       self.fatal("Unhandled API exception for method: %s: %s" % (self.proxy.uri,msg))
 
     self.logger.debug("Response: %s" % (response.status_int))
@@ -729,7 +729,7 @@ class Jiraclient(object):
   def display_issue(self,issueID):
     uri = 'rest/api/latest/issue/%s' % issueID
     result = self.call_api('get',uri)
-    print json.dumps(result)
+    print(json.dumps(result))
 
   def fetch_issue(self,issueID):
     uri = 'rest/api/latest/issue/%s' % issueID
@@ -801,7 +801,7 @@ class Jiraclient(object):
 
   def read_password(self):
     if not self.options.password:
-      print "Please authenticate."
+      print("Please authenticate.")
       pw = getpass.getpass("Jira password: ")
       self.options.password = pw
 
@@ -1247,7 +1247,7 @@ class Jiraclient(object):
         yamldata = yaml.load(sys.stdin,Loader=yaml.SafeLoader)
       else:
         yamldata = yaml.load(file(self.options.template,"r"),Loader=yaml.SafeLoader)
-    except Exception,details:
+    except Exception as details:
       self.fatal("Failed to parse YAML template: %s" % details)
 
     stories = None
@@ -1383,7 +1383,7 @@ class Jiraclient(object):
       # We need to know issue type to have access to custom fields
       try:
         itype = i['fields']['issuetype']['name']
-      except Exception, details:
+      except Exception as details:
         self.fatal("Cannot determine issue type of issue %s: %s" % (self.options.issueID, details))
       issue = self.create_issue_obj(itype,defaults=False)
       return self.modify_issue(self.options.issueID,issue)
@@ -1427,20 +1427,20 @@ class Jiraclient(object):
             fd = open(jsonpath,'r')
             try:
               jsondata = fd.read()
-            except Exception,msg:
+            except Exception as msg:
               self.fatal("Error reading jsondata: %s" % msg)
             fd.close()
             try:
               payload = json.dumps(json.loads(jsondata))
-            except Exception,msg:
+            except Exception as msg:
               self.fatal("Error parsing jsondata: %s" % msg)
           else:
             self.fatal("API error: file not found: %s" % self.options.jsondata)
       # Send payload with method
       try:
         response = self.call_api(self.options.method.lower(),self.options.api,payload=payload)
-        print json.dumps(response)
-      except Exception, details:
+        print(json.dumps(response))
+      except Exception as details:
         self.fatal("API error: bad method: %s" % details)
       return
 
@@ -1468,7 +1468,7 @@ class Jiraclient(object):
       issue = self.create_issue_obj(self.options.issuetype,defaults=defaults)
       try:
         return self.create_issue(issue)
-      except Exception, details:
+      except Exception as details:
         self.fatal("Failed to create issue. Reason: %r" % details)
 
     # Set epic link if specified
@@ -1491,7 +1491,7 @@ def main():
   try:
     A.run()
   except KeyboardInterrupt:
-    print "Exiting..."
+    print("Exiting...")
     return
 
 if __name__ == "__main__":
