@@ -15,14 +15,14 @@ class WorklogReport(object):
         uri = 'rest/api/latest/issue/%s' % issueID
         result = self.client.call_api('get',uri)
         for log in result['fields']['worklog']['worklogs']:
-          print "%s %s %s" % (issueID,log['author']['name'],log['comment'])
+          print("%s %s %s" % (issueID,log['author']['name'],log['comment']))
 
 def main():
     A = WorklogReport()
     try:
         A.run()
     except KeyboardInterrupt:
-        print "Exiting..."
+        print("Exiting...")
         return
 
 if __name__ == "__main__":
